Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(11)

Unified Diff: editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameTypeProcessorTest.java

Issue 12340077: Initial binding of RenameRefactoring service to Eclipse. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameTypeProcessorTest.java
diff --git a/editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameTypeProcessorTest.java b/editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameTypeProcessorTest.java
index c9b368770b9190ccb569b98a38e97308e9c4d60a..a61bb899d6a72bb1773162d159b9d2cf8149684b 100644
--- a/editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameTypeProcessorTest.java
+++ b/editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameTypeProcessorTest.java
@@ -17,7 +17,7 @@ import com.google.dart.tools.core.model.CompilationUnit;
import com.google.dart.tools.core.model.Type;
import com.google.dart.tools.internal.corext.refactoring.rename.RenameTypeProcessor;
import com.google.dart.tools.internal.corext.refactoring.util.ReflectionUtils;
-import com.google.dart.tools.ui.internal.refactoring.RenameSupport;
+import com.google.dart.tools.ui.internal.refactoring.RenameSupport_OLD;
import org.eclipse.ltk.core.refactoring.RefactoringStatus;
import org.eclipse.ui.IWorkbenchWindow;
@@ -32,10 +32,10 @@ public final class RenameTypeProcessorTest extends RefactoringTest {
private static boolean renameUnit = false;
/**
* Uses {@link RenameSupport} to rename {@link Type}.
*/
private static void renameType(Type type, String newName) throws Exception {
- RenameSupport renameSupport = RenameSupport.create(type, newName);
+ RenameSupport_OLD renameSupport = RenameSupport_OLD.create(type, newName);
// we rename type Test in unit Test.dart and usually don't want to rename unit
{
RenameTypeProcessor renameTypeProcessor = ReflectionUtils.invokeMethod(
@@ -32,10 +32,10 @@ public final class RenameTypeProcessorTest extends RefactoringTest {
private static boolean renameUnit = false;
/**
- * Uses {@link RenameSupport} to rename {@link Type}.
+ * Uses {@link RenameSupport_OLD} to rename {@link Type}.
*/
private static void renameType(Type type, String newName) throws Exception {
« no previous file with comments | « editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/RenameTypeParameterProcessorTest.java ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698